<?php $TRANSLATIONS = array(
"Music" => "Musik",
"songs" => "sange",
"albums" => "albummer",
"Add to playlist" => "Føj til afspilningsliste",
"Add album to playlist" => "Tilføj album til afspilningsliste",
"Play" => "Afspil",
"Pause" => "Pause",
"Previous" => "Forrige",
"Next" => "Næste",
"Mute" => "Lydløs",
"Unmute" => "Lyd til",
"Rescan Collection" => "Genskan Samling",
"Artist" => "Kunstner",
"Album" => "Album",
"Title" => "Titel",
"Media" => "Medier",
"Ampache address:" => "Ampache-adresse:"
);
